# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['slam',
 'slam.ext',
 'slam.ext.application',
 'slam.ext.changelog_update_automation',
 'slam.ext.checks',
 'slam.ext.project_handlers',
 'slam.ext.release',
 'slam.ext.vcs_hosts',
 'slam.util',
 'slam.util.external']

package_data = \
{'': ['*']}

install_requires = \
['PyYAML>=6.0,<7.0',
 'beautifulsoup4>=4.10.0,<5.0.0',
 'cleo>=1.0.0a4',
 'databind.core>=1.4.0,<2.0.0',
 'databind.json>=1.4.0,<2.0.0',
 'flit>=3.6.0,<4.0.0',
 'nr.util>=0.6.3,<0.7.0',
 'poetry-core>=1.1.0a6,<2.0.0',
 'ptyprocess>=0.7.0,<0.8.0',
 'pygments>=2.11.2,<3.0.0',
 'requests>=2.27.1,<3.0.0',
 'tomli>=2.0.0,<3.0.0',
 'twine>=3.7.0,<4.0.0']

entry_points = \
{'console_scripts': ['slam = slam.__main__:main'],
 'slam.plugins.application': ['changelog = '
                              'slam.ext.application.changelog:ChangelogCommandPlugin',
                              'check = '
                              'slam.ext.application.check:CheckCommandPlugin',
                              'info = '
                              'slam.ext.application.info:InfoCommandPlugin',
                              'install = '
                              'slam.ext.application.install:InstallCommandPlugin',
                              'link = '
                              'slam.ext.application.link:LinkCommandPlugin',
                              'publish = '
                              'slam.ext.application.publish:PublishCommandPlugin',
                              'release = '
                              'slam.ext.application.release:ReleaseCommandPlugin',
                              'test = '
                              'slam.ext.application.test:TestCommandPlugin'],
 'slam.plugins.changelog_update_automation': ['github-actions = '
                                              'slam.ext.changelog_update_automation.github_actions:GithubActionsChangelogUpdateAutomationPlugin'],
 'slam.plugins.check': ['changelog = '
                        'slam.ext.checks.changelog:ChangelogValidationCheckPlugin',
                        'general = slam.ext.checks.general:GeneralChecksPlugin',
                        'poetry = slam.ext.checks.poetry:PoetryChecksPlugin',
                        'release = '
                        'slam.ext.checks.release:ReleaseChecksPlugin'],
 'slam.plugins.release': ['changelog_release = '
                          'slam.ext.release.changelog:ChangelogReleasePlugin',
                          'source_code_version = '
                          'slam.ext.release.source_code_version:SourceCodeVersionReferencesPlugin'],
 'slam.plugins.vcs_host_detector': ['github = '
                                    'slam.ext.vcs_hosts.github:GithubVcsHostDetector'],
 'slam.plugins.vcs_host_provider': ['github = '
                                    'slam.ext.vcs_hosts.github:GithubVcsHostProvider'],
 'slam.plugins.version_incrementing_rule': ['major = '
                                            'slam.ext.version_incrementing_rule:major',
                                            'minor = '
                                            'slam.ext.version_incrementing_rule:minor',
                                            'patch = '
                                            'slam.ext.version_incrementing_rule:patch',
                                            'premajor = '
                                            'slam.ext.version_incrementing_rule:premajor',
                                            'preminor = '
                                            'slam.ext.version_incrementing_rule:preminor',
                                            'prepatch = '
                                            'slam.ext.version_incrementing_rule:prepatch',
                                            'prerelease = '
                                            'slam.ext.version_incrementing_rule:prerelease']}

setup_kwargs = {
    'name': 'slam-cli',
    'version': '1.0.0a13',
    'description': 'Slam is a command-line utility for developing Python applications.',
    'long_description': '# Slam\n\nSlam is a CLI that provides utilities for developing on Python projects. It works well with\n[Poetry][] projects in particular, but you\'re not required to use it.\n\n  [Poetry]: https://python-poetry.org/\n\n<!-- Available Commands -->\n```\nAvailable commands:\n  check                Run sanity checks on your Python project.\n  help                 Displays help for a command.\n  link                 Symlink your Python package with the help of Flit.\n  release              Create a new release of your Python package.\n  test                 Execute commands configured in [tool.slam.test].\n\n changelog\n  changelog add        Add an entry to the unreleased changelog via the CLI.\n  changelog convert    Convert Slam\'s old YAML based changelogs to new style TOML changelogs.\n  changelog format     Format the changelog in the terminal or in Markdown format.\n  changelog update-pr  Update the pr field of changelog entries in a commit range.\n```\n<!-- /Available Commands -->\n\n### Installation\n\nIt is recommended to install Slam via Pipx, but you can also install it with Pip directly.\n\n    $ pipx install slam-cli\n\n> __Note__: Currently, Slam relies on an alpha version of `poetry-core` (`^1.1.0a6`). If you install it into\n> the same environment as Poetry itself, you may also need to use an alpha version of Poetry (e.g. `1.2.0a2`).\n\n---\n\n<p align="center">Copyright &copy; 2022 Niklas Rosenstein</p>\n',
    'author': 'Niklas Rosenstein',
    'author_email': 'rosensteinniklas@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
